@@ -19,8 +19,7 @@ class Buffer():
         self.max_cache_length = max_cache_length
         self.push_method = push_method
 
-        self.stop_flag = threading.Event()
-        self.timer = RepeatedTimer(self.stop_flag, self.flush_cache, max_cache_timeout)
+        self.timer = RepeatedTimer(self.flush_cache, max_cache_timeout)
         self.timer.start()
         return
 
