@@ -6,7 +6,7 @@ from tqdm import tqdm
 import logging
 import json
 import datetime as dt
-import packaging
+import packaging.version as pack_version
 
 logger = logging.getLogger('pyhectiqlab')
 logger.setLevel(logging.WARNING)
@@ -27,8 +27,8 @@ def upload_dataset(source_path: str, dataset_name: str, run_id: str = None, vers
     manager = load_event_manager()
 
     if version is not None:
-        v = packaging.version.parse(version)
-        assert isinstance(v, packaging.version.Version), 'Cannot use legacy version names. Use a format major.minor.micro.'
+        v = pack_version.parse(version)
+        assert isinstance(v, pack_version.Version), 'Cannot use legacy version names. Use a format major.minor.micro.'
         updated_version = f'{v.major}.{v.minor}.{v.micro}'
         assert updated_version==version, f'Please change version to {updated_version}.'
 
@@ -47,7 +47,7 @@ def upload_dataset(source_path: str, dataset_name: str, run_id: str = None, vers
         full_paths = {os.path.basename(source_path): os.path.abspath(source_path) }
         num_bytes = os.path.getsize(source_path)
     args = (run_id, filenames, full_paths, num_bytes, dataset_name, short_description, version)
-    manager.add_event("add_dataset", args, async_method=False)
+    return manager.add_event("add_dataset", args, async_method=False)
 
 def download_dataset(dataset_name: str, project_id: str = None, version: str = None, 
     save_path: str = './', overwrite: bool = False):
@@ -76,7 +76,7 @@ def download_dataset(dataset_name: str, project_id: str = None, version: str = N
 
     if os.path.isdir(dirpath) and overwrite==False:
         logger.error(f'Dataset is already downloaded at {dirpath}. Delete this folder or set overwrite==True to download again.')
-        return
+        return dirpath
 
     if os.path.isdir(dirpath)==False:
         os.makedirs(dirpath)
