@@ -27,12 +27,12 @@ class LabCallback(tf.keras.callbacks.Callback):
         self.global_step += 1
         for metric in logs.keys():
             metric_val = logs[metric]
-            self._run.add_metrics(f'{metric}{self.annots['train']}', value=metric_val, step=self.global_step)
+            self._run.add_metrics(f"{metric}{self.annots['train']}", value=metric_val, step=self.global_step)
 
     def on_test_batch_end(self, batch, logs=None):
         for metric in logs.keys():
             metric_val = logs[metric]
-            self._run.add_metrics(f'{metric}{self.annots['val']}', value=metric_val, step=self.global_step)
+            self._run.add_metrics(f"{metric}{self.annots['val']}", value=metric_val, step=self.global_step)
 
     def on_train_batch_begin(self, batch, logs=None):
         pass
\ No newline at end of file
